==> dde-network-core_1.0.57.orig.tar.xz: dde-network-core-1.0.57/dss-network-plugin/translations/dss-network-plugin_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 mensaje nuevo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Conectando %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 conectado</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 desconectado</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>No se puede conectar %1, por favor, compruebe el router o el cable de red.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>No se puede conectar %1, por favor, manténgase más cerca del router inalámbrico</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Fallo de conexión, no se puede conectar %1, contraseña incorrecta</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Se requiere una contraseña para conectarse %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>No se ha podido encontrar la red WLAN 802.11 %1</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Conexión cableada</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Punto de acceso</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de seguridad</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de red</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primario</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefijo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo deshabilitado</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado pero sin acceso a Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Sin conexión</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de red desconectado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentificando</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obteniendo dirección IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicto de IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Fallido</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Obtención de la dirección</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Red cableada</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Red cableada %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Red inalámbrica</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Red inalámbrica %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo deshabilitado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de red desconectado</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Sin conexión</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado pero sin acceso a Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Conexión fallida</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicto de IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Desactivar conexión por cable</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Activar conexión por cable</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Desactivar conexión inalámbrica</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Activar conexión inalámbrica</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desactivar red</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Activar red</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ajustes de red</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dss-network-plugin/translations/dss-network-plugin_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 mensaje nuevo</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Red inalámbrica</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Red cableada</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Conectando %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 conectado</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 desconectado</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>No se puede conectar %1, por favor, compruebe el router o el cable de red.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>No se puede conectar %1, por favor, manténgase más cerca del router inalámbrico</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Fallo de conexión, no se puede conectar %1, contraseña incorrecta</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Se requiere una contraseña para conectarse %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>No se ha podido encontrar la red WLAN 802.11 %1</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectarse a una red oculta</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nombre (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Punto de acceso</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocolo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo de seguridad</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de red</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primario</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefijo</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocidad</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo deshabilitado</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado pero sin acceso a Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Sin conexión</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de red desconectado</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentificando</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obteniendo dirección IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicto de IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Fallido</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Obtención de la dirección</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Red cableada</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Red cableada %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Red inalámbrica</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Red inalámbrica %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo deshabilitado</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cable de red desconectado</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Sin conexión</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectando</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectado pero sin acceso a Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Conexión fallida</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflicto de IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Desactivar conexión por cable</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Activar conexión por cable</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Desactivar conexión inalámbrica</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Activar conexión inalámbrica</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Desactivar red</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Activar red</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ajustes de red</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Conexión cableada</translation>
    </message>
</context>
</TS>
